@@ -2,7 +2,7 @@
 
 # https://github.com/billythegoat356 https://github.com/loTus04 https://github.com/CSM-BlueRed
 
-# Version : 1.6 (added credits)
+# Version : 1.7
 
 # based on pyfade anc pycenter, R.I.P
 
@@ -13,7 +13,6 @@ from os import name as _name, system as _system, get_terminal_size as _terminal_
 from sys import stdout as _stdout
 from time import sleep as _sleep
 from threading import Thread as _thread
-from webbrowser import open as website
 
 
 if _name == 'nt':
@@ -24,15 +23,6 @@ if _name == 'nt':
                     ("visible", c_byte)]
 
 
-def credits():
-    System.Clear()
-    text = "Join discord.gg/plague for more Python Tools!"
-    System.Title(text)
-    Anime.Fade(Center.Center(text), Colors.blue_to_red, Colorate.Horizontal, time=3)
-    website("https://discord.gg/plague")
-    System.Clear()
-
-
 class System:
 
     """
@@ -898,5 +888,4 @@ class Box:
         return box + "\n" + addspace * " " + content + addspace * " " + "\n" + box
 
 
-System.Init()
-credits()
\ No newline at end of file
+System.Init()
\ No newline at end of file
